summaryrefslogtreecommitdiffstats
path: root/bibletime/backend/clanguagemgr.h
diff options
context:
space:
mode:
Diffstat (limited to 'bibletime/backend/clanguagemgr.h')
-rw-r--r--bibletime/backend/clanguagemgr.h52
1 files changed, 26 insertions, 26 deletions
diff --git a/bibletime/backend/clanguagemgr.h b/bibletime/backend/clanguagemgr.h
index 2acc4c7..4ca0787 100644
--- a/bibletime/backend/clanguagemgr.h
+++ b/bibletime/backend/clanguagemgr.h
@@ -13,11 +13,11 @@
#define CLANGUAGEMGR_H
//Qt includes
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qvaluelist.h>
-#include <qmap.h>
-#include <qdict.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
+#include <tqvaluelist.h>
+#include <tqmap.h>
+#include <tqdict.h>
/** Manages the anguages of BibleTime and provides functions to work with them.
* @author The BibleTime team
@@ -42,30 +42,30 @@ public:
Language(const Language&);
/** Constructor which takes all necessary data.
*/
- Language(const QString& abbrev, const QString& englishName, const QString& translatedName, const QStringList& altAbbrevs = QStringList());
+ Language(const TQString& abbrev, const TQString& englishName, const TQString& translatedName, const TQStringList& altAbbrevs = TQStringList());
/** Destructor.
*/
~Language();
/** Returns the abbreviation.
* @return The abbreviation of the chosen language.
*/
- inline const QString& abbrev() const;
+ inline const TQString& abbrev() const;
/** Returns the translated name.
* @return The translated name of the language.
*/
- inline const QString& translatedName() const;
+ inline const TQString& translatedName() const;
//always define inlines in the header file, or make them not inline.
/** The english name of the language.
* @return The english name of the chosen language.
*/
- inline const QString& name() const {
+ inline const TQString& name() const {
return m_englishName;
}
/** The alternative abbreviations which are avalable for this language.
* @return A pointer to the list of alternate abbreviations
*/
- inline const QStringList* const alternativeAbbrevs() const {
+ inline const TQStringList* const alternativeAbbrevs() const {
return m_altAbbrevs;
};
@@ -76,16 +76,16 @@ public:
inline const bool isValid() const;
private:
- QString m_abbrev;
- QString m_englishName;
- QString m_translatedName;
- QStringList* m_altAbbrevs;
+ TQString m_abbrev;
+ TQString m_englishName;
+ TQString m_translatedName;
+ TQStringList* m_altAbbrevs;
};
- typedef QPtrList<CLanguageMgr::Language> LanguageList;
+ typedef TQPtrList<CLanguageMgr::Language> LanguageList;
- typedef QDict<Language> LangMap;
- typedef QDictIterator<Language> LangMapIterator;
+ typedef TQDict<Language> LangMap;
+ typedef TQDictIterator<Language> LangMapIterator;
/** Constructor.
*/
@@ -95,7 +95,7 @@ public:
virtual ~CLanguageMgr();
/**
* Returns the standard languages available as standard. Does nothing for Sword.
* @return A QDict<Language> map which contains all known languages
*/
inline const CLanguageMgr::LangMap* const languages() const;
/**
@@ -107,17 +107,17 @@ public:
* @param abbrev The language abbreviation
* @return Pointer to a language for the given string abbreviation.
*/
- const CLanguageMgr::Language* const languageForAbbrev( const QString& abbrev ) const;
+ const CLanguageMgr::Language* const languageForAbbrev( const TQString& abbrev ) const;
/** Language for english name.
* @param abbrev The english language name.
* @return Pointer to a language for the given name
*/
- const CLanguageMgr::Language* const languageForName( const QString& language ) const;
+ const CLanguageMgr::Language* const languageForName( const TQString& language ) const;
/** Language for translated language name.
* @param abbrev The translated language name
* @return Pointer to a language for the given translated language name
*/
- const CLanguageMgr::Language* const languageForTranslatedName( const QString& language ) const;
+ const CLanguageMgr::Language* const languageForTranslatedName( const TQString& language ) const;
/** Default language so we don't return NULL pointers.
* @return Pointer to the default language
*/
@@ -125,14 +125,14 @@ public:
private:
void init();
- inline const QStringList makeStringList(const QString& abbrevs) {
- return QStringList::split( ";", abbrevs, false );
+ inline const TQStringList makeStringList(const TQString& abbrevs) {
+ return TQStringList::split( ";", abbrevs, false );
}
mutable LangMap m_langMap;
Language m_defaultLanguage;
- //typedef QPtrList<CLanguageMgr::Language> LanguageList;
+ //typedef TQPtrList<CLanguageMgr::Language> LanguageList;
static LanguageList m_langList;
static LanguageList m_cleanupLangPtrs;
@@ -149,7 +149,7 @@ inline const bool CLanguageMgr::Language::isValid() const {
return (!abbrev().isEmpty() && !name().isEmpty());
}
-inline const QString& CLanguageMgr::Language::abbrev() const {
+inline const TQString& CLanguageMgr::Language::abbrev() const {
if (m_altAbbrevs && m_abbrev.isEmpty() && m_altAbbrevs->count()) { //no standard abbrev but alternative ones
return m_altAbbrevs->first();
}
@@ -157,7 +157,7 @@ inline const QString& CLanguageMgr::Language::abbrev() const {
return m_abbrev;
}
-inline const QString& CLanguageMgr::Language::translatedName() const {
+inline const TQString& CLanguageMgr::Language::translatedName() const {
return m_translatedName;
}
@@ -95,7 +95,7 @@ public:
/**
* Returns the standard languages available as standard. Does nothing for Sword.
- * @return A QDict<Language> map which contains all known languages
+ * @return A TQDict<Language> map which contains all known languages
*/
inline const CLanguageMgr::LangMap* const languages() const;